function varargout = PushButtons(varargin)
% PUSHBUTTONS M-file for PushButtons.fig
%      PUSHBUTTONS, by itself, creates a new PUSHBUTTONS or raises the existing
%      singleton*.
%
%      H = PUSHBUTTONS returns the handle to a new PUSHBUTTONS or the handle to
%      the existing singleton*.
%
%      PUSHBUTTONS('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in PUSHBUTTONS.M with the given input arguments.
%
%      PUSHBUTTONS('Property','Value',...) creates a new PUSHBUTTONS or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before PushButtons_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to PushButtons_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Copyright 2002-2003 The MathWorks, Inc.

% Edit the above text to modify the response to help PushButtons

% Last Modified by GUIDE v2.5 29-Jan-2007 11:06:46

% Begin initialization code - DO NOT EDIT
   gui_Singleton = 1;
   gui_State = struct('gui_Name',       mfilename, ...
                      'gui_Singleton',  gui_Singleton, ...
                      'gui_OpeningFcn', @PushButtons_OpeningFcn, ...
                      'gui_OutputFcn',  @PushButtons_OutputFcn, ...
                      'gui_LayoutFcn',  [] , ...
                      'gui_Callback',   []);
   if nargin && ischar(varargin{1})
       gui_State.gui_Callback = str2func(varargin{1});
   end

   if nargout
       [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
   else
       gui_mainfcn(gui_State, varargin{:});
   end
% End initialization code - DO NOT EDIT


% --- Executes just before PushButtons is made visible.
function PushButtons_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to PushButtons (see VARARGIN)

   % Choose default command line output for PushButtons
   handles.output = hObject;

   % Update handles structure
   guidata(hObject, handles);

   % UIWAIT makes PushButtons wait for user response (see UIRESUME)
   % uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = PushButtons_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

   % Get default command line output from handles structure
   varargout{1} = handles.output;


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
   figure;
   plot( [0,3], [1,5] );

% --- Executes on button press in pushbutton2.
function pushbutton2_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
   figure;
   fplot( 'x*x', [-3,3] );

% --- Executes on button press in pushbutton3.
function pushbutton3_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
   figure;
   z = [0 0; 1 1];
   surf( z );
